A simple utility for working with lines.
Provides a method to get the distance from a point to the Line.
Structs
- Line
- A line defined by 2 points. A line defined by 2 points.
- Line
Distance - Computes the distance to a line.
A simple utility for working with lines.
Provides a method to get the distance from a point to the Line.